WebLogo 3 - Create
Author: Gavin E. Crooks

WebLogo Create Layout Template

#

WebLogo 3: Create

## Sequence Data Input:

URL:
${error_message} ${sequences}
Download to local drive
Title:
Output Format:
Sequence type
Logo-size:
Stacks per Line:
Ignore lower case:
Units:
First position number:
Logo range: -
Figure label:
Scale stack widths:
Composition:
or % CG
Error bars:
Show Sequence Ends labels:
Version fineprint:
X-axis Label:
Y-axis Label:
Y-axis scale:
Y-axis tic spacing:
Color scheme:
Symbols:
Color: